<?php
/*
Plugin Name:  GDPR Notice
Plugin URI:   https://www.orcas.de/wordpress-plugin/gdpr-notice/
Description:  Helps to make your site more GDPR conform.
Version:      1.3.13
Author:       orcas
Author URI:   https://www.orcas.de/
License:      GPL2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
Text Domain:  gdpr-notice-original
Domain Path:  /languages
*/
if (!defined('ABSPATH')) {
	exit;
}

//if (is_dir(dirname(__FILE__) . '/extension/pro/') && is_file(dirname(__FILE__) . '/extension/pro/pro.php')) {
//	require_once dirname(__FILE__) . '/extension/pro/pro.php';
//}

define('GDPR_PLUGIN_ROOT', basename(dirname(__FILE__)));

class GDPRNotice {

	public static $pageTypes;

	private static $instance;

	private static $loadedExtensions;

	public static function instance() {
		if (null == self::$instance) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	function __construct() {

		if (isset($_POST['action']) && $_POST['action'] === 'privacy_content') {
			$this->getPageContent();
		} else {
			add_action('init', array($this, 'init'), 5);
			add_action('plugins_loaded', array($this, 'loadTextdomain'));
			add_action('plugins_loaded', array($this, 'checkPrivacyStatus'));
			add_action('wp_ajax_privacy_content', array($this, 'getPageContent'));

			add_action('gdpr_print_pages', array($this, 'maybePrintDefaultMessage'));
			add_action('gdpr_print_pages', array($this, 'printLinks'));
			add_action('gdpr_informational_content', array($this, 'displayInformationalContent'));

			add_filter('clean_url', array($this, 'cleanUrl'), 10, 2);

			if (is_admin()) {
				require_once dirname(__FILE__) . '/admin/admin.php';
			}

			if (!session_id()) {
				session_start();
			}
		}
	}

	public static function getCookieValue() {
		$data = array();
		if (isset($_COOKIE['gdpr-accepted'])) {
			$data = json_decode(base64_decode($_COOKIE['gdpr-accepted']), true);
		}
		$data = wp_parse_args($data, array(
			'time'   => 0,
			'accept' => array(
				0 => false
				// This will never map to anything, since posts cannot have an ID of 0. This is purely to prevent non-blocking behaviour if the user
				// has not yet selected anything. If the user has already made their choice this default value will not be applied.
			),
		));

		return $data;
	}

	public function loadTextdomain() {
		load_plugin_textdomain('gdpr-notice-original', false, basename(dirname(__FILE__)) . '/languages');
		load_plugin_textdomain('orcas-upgrade', false, basename(dirname(__FILE__)) . '/include/languages');

		self::$pageTypes = array(
			'message'         => __('Message', 'gdpr-notice-original'),
			'info_message'    => __('Informational message', 'gdpr-notice-original'),
			'info_link'       => __('Informational link', 'gdpr-notice-original'),
			'title'           => __('Page title', 'gdpr-notice-original'),
			'reject_message'  => __('Reject message', 'gdpr-notice-original'),
			'changed_message' => __('Policy changed message', 'gdpr-notice-original'),
		);
	}

	function getPageContent() {
		$post = get_post(intval($_POST['post_id']));
		if ($post && $post->post_type == 'gdpr-notice-page') {
			echo wpautop($post->post_content);
		} else {
			$additionalLinks = static::getAdditionalLinks();
			foreach ($additionalLinks as $l) {
				$id = sprintf('%1$d', $this->getId($l));
				if ($id == $_POST['post_id']) {
					echo wpautop($l->post_content);
					break;
				}
			}
		}
		wp_die();
	}

	function init() {
		register_post_type('gdpr-notice-page',
			array(
				'labels'           => array(
					'name'          => __('GDPR messages', 'gdpr-notice-original'),
					'singular_name' => __('GDPR message', 'gdpr-notice-original')
				),
				'public'           => false,
				'show_ui'          => true,
				'show_in_nav_menu' => false,
				'has_archive'      => false,
				'rewrite'          => array('slug' => 'privacy'),
				'show_in_menu'     => false,
				'supports'         => array('title', 'editor', 'page-attributes', 'revisions'),
			)
		);

		register_post_status('disabled', array(
			'label'                     => _x('Disabled', 'post status', 'gdpr-notice-original'),
			'public'                    => true,
			'private'                   => false,
			'internal'                  => false,
			'exclude_from_search'       => true,
			'show_in_admin_all_list'    => true,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop(
				'Disabled <span class="count">(%s)</span>',
				'Disabled <span class="count">(%s)</span>',
				'gdpr-notice-original'
			),
		));
	}

	public function cleanUrl($cleanUrl, $originalUrl) {
		if ('{GDPR_RESELECT}' == $originalUrl) {
			if ((is_admin() && "nav-menus" == get_current_screen()->id) || (isset($_POST['action']) && 'add-menu-item' == $_POST['action'])) {
				// We do not want to replace our placeholder with the actual link in the menu editor.
				return $originalUrl;
			}

			if ("yes" == get_option("gdpr-use-custom-url", "no") && "normal" == get_option('gdpr_display_mode', 'normal')) {
				return add_query_arg(
					array(
						'gdpr_reselect' => '1',
						'return_to'     => urlencode($_SERVER['REQUEST_URI']),
					),
					home_url(get_option('gdpr-custom-url')));
			} else {
				return add_query_arg('gdpr_reselect', '1');
			}
		}

		return $cleanUrl;
	}

	private static function is_robot() {
		// search engine names courtesy of https://perishablepress.com/list-all-user-agents-top-search-engines/
		$bots = array_map('strtolower', array_merge(array(
			'aolbuild',
			'baidu',
			'bingbot',
			'bingpreview',
			'msnbot',
			'duckduckgo',
			'adsbot-google',
			'googlebot',
			'mediapartners-google',
			'teoma',
			'slurp',
			'wordpress',
			'yandex',
			'letsencrypt',
		), get_option('gdpr-custom-robots', array())));  // Merge static bot names with custom bot names

		return (bool) preg_match("/" . join('|', $bots) . "/", strtolower($_SERVER['HTTP_USER_AGENT']));
	}

	private static function isCookieExpired() {
		global $wpdb;
		$data          = json_decode(base64_decode($_COOKIE['gdpr-accepted']), true);
		$cookieVersion = intval($data['time']);
		$query         = "SELECT `post_id` FROM {$wpdb->prefix}postmeta WHERE `post_id` IN (SELECT `post_id` FROM {$wpdb->prefix}posts WHERE `post_status`=\"publish\" AND `post_type` = \"gdpr-notice-page\") AND `meta_key` = \"version\" AND `meta_value` > {$cookieVersion};";
		$rows          = $wpdb->get_results($query);

		return 0 != count($rows);
	}

	private static function is_policy_accepted() {
		if (isset($_GET['gdpr_reselect'])) {
			// "Pretend" the user does not have the policies accepted, so they'll be asked again
			return false;
		}
		if (is_user_logged_in()) {
			if (!isset($_COOKIE['gdpr-accepted'])) {
				$data = get_user_meta(get_current_user_id(), 'gdpr_accepted', true);
				if (is_array($data)) {
					$cookieValue = base64_encode(json_encode($data));
					setcookie('gdpr-accepted', $cookieValue, time() + 30 * 24 * 60 * 60, COOKIEPATH, COOKIE_DOMAIN);
					$_COOKIE['gdpr-accepted'] = $cookieValue;
				}
			}
		}
		if (isset($_COOKIE['gdpr-accepted']) && false !== $_COOKIE['gdpr-accepted']) {
			return !self::isCookieExpired();
		}

		return false;
	}

	private static function acceptPrivacyPolicy() {
		$data = array('time' => time(), 'accept' => array());
		if (isset($_POST['accept'])) {
			foreach ($_POST['accept'] as $key => $accepted) {
				$data['accept'][ $key ] = 'on' == $accepted;
			}
		}
		if (is_user_logged_in()) {
			update_user_meta(get_current_user_id(), 'gdpr_accepted', $data);
		}
		$data = base64_encode(json_encode($data));
		setcookie('gdpr-accepted', $data, time() + 30 * 24 * 60 * 60, COOKIEPATH, COOKIE_DOMAIN);
		$_COOKIE['gdpr-accepted'] = $data;
		if ("yes" == get_option("gdpr-use-custom-url", "no") && isset($_GET['return_to'])) {
			wp_safe_redirect(remove_query_arg('gdpr_reselect', home_url($_GET['return_to'])));
		} else {
			wp_safe_redirect(remove_query_arg('gdpr_reselect'));
		}
		exit();
	}

	private static function rejectPrivacyPolicy() {
		$_SESSION['privacy-accepted'] = false;
		add_filter('gdpr_display_page_types', array(__CLASS__, 'addRejectedMessages'));
		setcookie('gdpr-accepted', false, 30 * 24 * 60 * 60, COOKIEPATH, COOKIE_DOMAIN);
		wp_logout();
	}

	public static function addRejectedMessages($types) {
		$types[] = 'reject_message';

		return $types;
	}

	public function maybePrintDefaultMessage($links) {
		if (empty($links)) {
			echo wp_kses_post(nl2br(__(
				"According to the GDPR we have to obtain your permission if we're using external services. Do you agree with the use of external services? You can revoke your consent at any time by deleting cookies in your browser.", 'gdpr-notice-original')));
		}
	}

	public function get_post_data($item, $key) {
		if (preg_match("/[0-9]+/", $item->ID)) {
			return get_post_meta($item->ID, $key, true);
		} else {
			return $item->$key;
		}
	}

	public static function getIdFromText($text) {
		return absint(crc32("additional-gdpr-{$text}"));
	}

	public function getId($item) {
		if (preg_match("/[0-9]+/", $item->ID)) {
			return $item->ID;
		} else {
			return absint(crc32($item->ID));
		}
	}

	public function printLinks($links) {
		$linkChain = false;
		$cookie    = GDPRNotice::getCookieValue();
		/** @var WP_Post $link */
		foreach ($links as $link) {
			switch ($pageType = $this->get_post_data($link, 'page_type')) {
				case 'reject_message':
				case 'changed_message':
				case 'message':
				case 'info_message':
					if ($linkChain) {
						$linkChain = false;
						echo '</ul>';
					}
					$classes = sprintf('message message-%1$d', $this->getId($link));
					if ("reject_message" == $pageType) {
						$classes .= " rejected";
					}
					printf('<article class="%s" id="message-%d">%s</article>', $classes, $this->getId($link), wpautop(wp_kses_post($link->post_content)));
					break;
				case 'link':
				case 'info_link':
				case 'tracking':
					if (!$linkChain) {
						$linkChain = true;
						echo '<ul class="link-list">';
					}
					$classes = sprintf('link message-%1$d', $this->getId($link));
					echo '<li>';
					if ('link' == $pageType || 'tracking' == $pageType) {
						if (isset($_GET['gdpr_reselect'])) {
							$id            = $this->getId($link);
							$defaultSelect = isset($cookie['accept'][ $id ]) ? $cookie['accept'][ $id ] : false;
						} else {
							$defaultSelect = false;
						}
						$checked = isset($_POST['accept'][ $this->getId($link) ]) ? 'on' == $_POST['accept'][ $this->getId($link) ] : $defaultSelect;
						printf('<input type="hidden" name="accept[%d]" value="off"/>', $this->getId($link));
						printf(
							'<input type="checkbox" value="on" name="accept[%1$d]" id="checkbox-%1$d" %2$s/><label for="checkbox-%1$d"><span class="on">%3$s</span><span class="off">%4$s</span><span class="knob"></span></label>',
							$this->getId($link),
							defined('GDPR_PRO') ? checked(true, $checked, false) : disabled(1, 1, false) . ' ' . checked(1, 1, false),
							esc_html_x('ON', 'Checkbox label', 'gdpr-notice-original'),
							esc_html_x('OFF', 'Checkbox label', 'gdpr-notice-original')
						);
					}
					if ('link' == $pageType && 'yes' == $this->get_post_data($link, 'link_required')) {
						$classes .= ' required';
					}
					printf(
						'<a href="%4$s" class="%1$s" id="message-%2$d" data-id="%2$d">%3$s</a></li>',
						$classes,
						$this->getId($link),
						$link->post_title,
						add_query_arg('gdpr_page', $this->getId($link))
					);
					if (class_exists('GDPRNoticePro')) {
						$rejected = GDPRNoticePro::instance()->getRejectedLinks();
						if (!empty($rejected[ $this->getId($link) ])) {
							printf('<li class="required">%s</li>', $rejected[ $this->getId($link) ]);
						}
					}
					break;
			}
		}
	}

	public static function getAdditionalLinks() {
		$additionalLinks = apply_filters('gdpr_notice_form', array());
		$links           = array();
		foreach ($additionalLinks as $l) {
			$std = new stdClass();
			if (isset($l['key'])) {
				$std->ID            = 'additional-gdpr-' . $l['key'];
				$std->page_type     = isset($l['type']) ? $l['type'] : '';
				$std->post_content  = isset($l['content']) ? $l['content'] : '';
				$std->post_title    = isset($l['title']) ? $l['title'] : '';
				$std->link_required = isset($l['required']) ? $l['required'] : false;
				$links[]            = $std;
			}
		}

		return $links;
	}

	public static function enqueueScripts() {
		wp_enqueue_script('gdpr-notice', plugin_dir_url(__FILE__) . 'view/assets/js/gdpr.js', array('jquery'), '1.0', true);
		wp_localize_script('gdpr-notice', 'GDPR_i10n', array(
			'ajaxUrl' => admin_url('admin-ajax.php'),
			'loading' => __('Loading...', 'gdpr-notice-original'),
		));
		$uploads = wp_get_upload_dir();
		if (file_exists($uploads['basedir'] . "/gdpr-notice/style.css")) {
			wp_enqueue_style('gdpr-notice', preg_replace('@https?\:@', '', $uploads['baseurl']) . "/gdpr-notice/style.css", array(), '1.0');
		} else {
			wp_enqueue_style('gdpr-notice', plugin_dir_url(__FILE__) . 'view/assets/css/style.css', array(), '1.0');
		}

		switch (get_option('gdpr_compact_position', 'br')) {
			case 'tl':
				$position = "top:15px; left:15px;";
				break;
			case 'tr':
				$position = "top:15px; right:15px;";
				break;
			case 'bl':
				$position = "bottom:15px; left:15px;";
				break;
			case 'br':
			default:
				$position = "bottom:15px; right:15px;";
				break;
		}
		wp_add_inline_style('gdpr-notice', ".gdpr-notice-form {{$position}}");
		if (isset($_GET['gdpr_page'])) {
			wp_add_inline_style('gdpr-notice', '#gdpr-post-content::before, #gdpr-post-content .close {display: none;}');
		}
	}

	public static function footer() {
		static::printNotice(false);
	}

	private static function displayNotice() {
		if ('yes' == get_option('gdpr_compact_display', 'no')) {
			// Legacy compact mode check
			$mode = 'compact';
		} else {
			$mode = get_option('gdpr_display_mode', 'normal');
		}

		switch ($mode) {
			case 'normal':
				if (!is_ssl() && "https" == substr(home_url(), 0, 5)) {
					// TODO Is there a better way to do this?
					wp_redirect(home_url($_SERVER['REQUEST_URI']));
					die();
				}

				wp_templating_constants();
				static::printNotice();
				die();
			case 'compact':
				add_action('wp_enqueue_scripts', array(__CLASS__, 'enqueueScripts'));
				add_action('wp_footer', array(__CLASS__, 'footer'));

				return;
			case 'invisible':
				return;
		}
	}

	private static function printNotice($completePage = true) {
		$links = get_posts(apply_filters('gdpr_link_params', array(
			'posts_per_page' => - 1,
			'post_type'      => 'gdpr-notice-page',
			'orderby'        => 'menu_order',
			'order'          => 'asc',
			'meta_query'     => array(
				array(
					'key'     => 'page_type',
					'value'   => apply_filters('gdpr_display_page_types', array('message', 'link', 'tracking')),
					'compare' => 'IN',
				)
			)
		)));

		$pageTitle = get_posts(apply_filters('gdpr_page_title_params', array(
			'posts_per_page' => 1,
			'post_type'      => 'gdpr-notice-page',
			'orderby'        => 'menu_order',
			'order'          => 'asc',
			'meta_query'     => array(
				array(
					'key'     => 'page_type',
					'value'   => 'title',
					'compare' => '=',
				)
			)
		)));

		$links = array_merge($links, static::getAdditionalLinks());

		if (empty($pageTitle)) {
			$pageTitle = __('Important notice', 'gdpr-notice-original');
		} else {
			$pageTitle = $pageTitle[0]->post_title;
		}
		$gdprPage = false;
		if (isset($_GET['gdpr_page'])) {
			$gdprPage = get_post($_GET['gdpr_page']);
		}
		ob_start();
		if ($completePage) {
			$page = locate_template("gdpr/notice-page.php");
			if ("" == $page) {
				$page = dirname(__FILE__) . '/view/notice-page.php';
			}
		} else {
			$page = locate_template("gdpr/notice.php");
			if ("" == $page) {
				$page = dirname(__FILE__) . '/view/notice.php';
			}
		}
		include $page;
		$content = ob_get_clean();
		echo $content;
	}

	private static function checkAcceptedCookie() {
		if (isset($_COOKIE['gdpr-accepted']) && self::isCookieExpired()) {
			add_action('gdpr_before_links', array(__CLASS__, 'displayExpiredMessage'));
		}
	}

	public static function displayExpiredMessage() {
		$messages = get_posts(apply_filters('gdpr_link_params', array(
			'posts_per_page' => - 1,
			'post_type'      => 'gdpr-notice-page',
			'orderby'        => 'menu_order',
			'order'          => 'asc',
			'meta_query'     => array(
				array(
					'key'     => 'page_type',
					'value'   => 'changed_message',
					'compare' => '=',
				)
			)
		)));
		/** @var WP_Post $message */
		foreach ($messages as $message) {
			printf('<article class="expired %s" id="message-%d">%s</article>', '', $message->ID, wpautop(wp_kses_post($message->post_content)));
		}
	}

	public function displayInformationalContent() {
		$messages = get_posts(apply_filters('gdpr_link_params', array(
			'posts_per_page' => - 1,
			'post_type'      => 'gdpr-notice-page',
			'orderby'        => 'menu_order',
			'order'          => 'asc',
			'meta_query'     => array(
				array(
					'key'     => 'page_type',
					'value'   => array('info_message', 'info_link'),
					'compare' => 'IN',
				)
			)
		)));
		$this->printLinks($messages);
	}

	function checkPrivacyStatus() {
		if (
			is_admin() || // Admins don't need to accept the privacy policy to not break stuff
			self::is_robot() || // NEVER show robots this notice! That would negatively impact our page ranking!
			self::is_policy_accepted() ||  // The privacy policies have been accepted, no need to do anything at this moment
			false !== stripos($_SERVER['REQUEST_URI'], 'cache') ||  // Do not block calls if requested URI indicates we might have requested cached data
			defined('XMLRPC_REQUEST') ||  // XML-RPC API should not be blocked
			defined('WP_CLI')  // Called from the console, which can't accept our policies
		) {
			// Bail if we determined we should not present the privacy notice
			return;
		}
		if (isset($_POST['privacy-accepted'])) {
			if (apply_filters('gdpr_required_check', true)) {
				self::acceptPrivacyPolicy();

				return;
			}
		} elseif (isset($_POST['privacy-rejected'])) {
			self::rejectPrivacyPolicy();
		} else {
			self::checkAcceptedCookie();
		}
		if ("yes" == get_option('gdpr-use-custom-url', 'no') && "normal" == get_option('gdpr_display_mode', 'normal') && !isset($_GET['return_to']) && !isset($_GET['gdpr_reselect'])) {
			wp_safe_redirect(
				add_query_arg(
					'return_to',
					urlencode($_SERVER['REQUEST_URI']),
					home_url(get_option('gdpr-custom-url'))
				)
			);
			exit();
		}
		self::displayNotice();
	}

	public static function activate() {
		$query = new WP_Query(array(
			'post_type' => 'gdpr-notice-page'
		));
		if (!$query->have_posts()) {
			load_plugin_textdomain('gdpr-notice-original', false, basename(dirname(__FILE__)) . '/languages');
			$locale  = explode('_', get_locale());
			$locale  = $locale[0];
			$posts   = array();
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'publish',
				'post_title'   => __('Important notice', 'gdpr-notice-original'),
				'post_content' => __('This page is for the "page title" type. The value of content field will be ignored. Only the value of title field will be shown to the front end user.', 'gdpr-notice-original'),
				'menu_order'   => 0,
				'meta_input'   => array(
					'page_type' => 'title',
					'language'  => $locale,  // language is not used for free version, but we'll keep track of the language for when pro is installed
					'_type'     => 'title',
				),
			));
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'publish',
				'post_title'   => __('Introduction', 'gdpr-notice-original'),
				'post_content' => __("According to the GDPR we have to obtain your permission if we're using external services. Do you agree with the use of external services? You can revoke your consent at any time by deleting cookies in your browser.", 'gdpr-notice-original'),
				'menu_order'   => 1,
				'meta_input'   => array(
					'page_type' => 'message',
					'language'  => $locale,  // language is not used for free version, but we'll keep track of the language for when pro is installed
					'_type'     => 'message',
				),
			));
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'publish',
				'post_title'   => __('Cookies', 'gdpr-notice-original'),
				'post_content' => __('This site uses cookies', 'gdpr-notice-original'),
				'menu_order'   => 50,
				'meta_input'   => array(
					'page_type' => 'info_link',
					'language'  => $locale,  // language is not used for free version, but we'll keep track of the language for when pro is installed
					'_type'     => 'cookies',
				),
			));
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'publish',
				'post_title'   => __('Privacy policy', 'gdpr-notice-original'),
				'post_content' => __('Insert your privacy policy terms here', 'gdpr-notice-original'),
				'menu_order'   => 51,
				'meta_input'   => array(
					'page_type' => 'info_link',
					'language'  => $locale,  // language is not used for free version, but we'll keep track of the language for when pro is installed
					'_type'     => 'privacy_policy',
				),
			));
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'publish',
				'post_title'   => __('Legal disclosure', 'gdpr-notice-original'),
				'post_content' => __('Insert your legal disclosure here', 'gdpr-notice-original'),
				'menu_order'   => 52,
				'meta_input'   => array(
					'page_type' => 'info_link',
					'language'  => $locale,  // language is not used for free version, but we'll keep track of the language for when pro is installed
					'_type'     => 'legal_notice',
				),
			));
			// Example pages
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'disabled',
				'post_title'   => __('Gravatar', 'gdpr-notice-original'),
				'post_content' => __('Gravatar is a service by the creators of WordPress, used to display user avatars on this page.', 'gdpr-notice-original'),
				'menu_order'   => 40,
				'meta_input'   => array(
					'page_type'            => 'link',
					'link_whitelist_regex' => ".*gravatar.*\n",
					'language'             => $locale,
					'_type'                => 'gravatar',
				),
			));
			$posts[] = wp_insert_post(array(
				'post_type'    => 'gdpr-notice-page',
				'post_status'  => 'disabled',
				'post_title'   => __('Google Analytics', 'gdpr-notice-original'),
				'post_content' => __('Google Analytics allows us to track user movement across our age to help us improve our service.', 'gdpr-notice-original'),
				'menu_order'   => 41,
				'meta_input'   => array(
					'page_type'         => 'tracking',
					'tracking_provider' => 'google-analytics',
					'language'          => $locale,
					'_type'             => 'google_analytics',
				),
			));

			if ("en" != $locale) {
				update_option('gdpr_sample_posts', $posts, false);
			}
		}

		new \de\orcas\extension\Analytics(__FILE__, 'activate');
	}

	public static function deactivate() {
		new \de\orcas\extension\Analytics(__FILE__, 'deactivate');
	}
}

// autoload should be loaded first, so extensions are present before GDPR instantiates
include_once __DIR__ . "/include/Analytics.php";
include_once __DIR__ . "/include/autoload.php";

GDPRNotice::instance();

register_activation_hook(__FILE__, array('GDPRNotice', 'activate'));
register_deactivation_hook(__FILE__, array('GDPRNotice', 'deactivate'));
